@@ -72,7 +72,7 @@ function evaluatePixel(samples) {{
         return f"let {self.initial_data_name} = new DataCube(samples, '{self.bands_dimension_name}', '{self.temporal_dimension_name}', true)"
 
     def write_update_output(self):
-        if self._output_dimensions is None:
+        if self._output_dimensions is None or not self.encode_result:
             return ""
         number_of_original_temporal_dimensions = len(
             [dim for dim in self._output_dimensions if dim.get("original_temporal", False)]
