@@ -163,7 +163,7 @@ function reduce_dimension(arguments) {{
     function reducer(arguments) {{
     {newline.join(node.write_function() for node in self.child_nodes)}
     {newline.join(node.write_call() for node in self.child_nodes)}
-        return {self.child_nodes[-1].node_id};
+        return {self.child_nodes[-1].node_varname_prefix + self.child_nodes[-1].node_id};
     }}
 
     const {{data, dimension}} = arguments; 
